"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _test = require("@playwright/test");
var _path = _interopRequireDefault(require("path"));
var _readConfigFile = require("../readConfigFile");
var _configUtils = require("./config-utils");
var _Configuration = _interopRequireDefault(require("./../configuration/Configuration"));
var _UserArgs = _interopRequireDefault(require("./../configuration/UserArgs"));
var _ConfigurationHelper = require("../configuration/ConfigurationHelper");
// overriding the application config's from project
const uatConfig = new _Configuration.default((0, _ConfigurationHelper.getApplicationConfig)());
const userArgConfig = new _Configuration.default(_UserArgs.default.parseToObject(process.argv.slice(2)));

// overriding the user config's from CLI
uatConfig.addAll(userArgConfig);
const {
  browsers,
  trace,
  video,
  isAuthMode,
  openReportOn,
  reportPath,
  bddMode,
  expectTimeout,
  testTimeout,
  authFilePath,
  viewport,
  featureFilesFolder,
  stepDefinitionsFolder,
  testIdAttribute,
  globalTimeout
} = uatConfig.getAll();
const projects = (0, _configUtils.getProjects)({
  browsers,
  isAuthMode,
  authFilePath,
  expectTimeout,
  testTimeout,
  viewport
});
const testDir = (0, _configUtils.getTestDir)(bddMode, process.cwd(), {
  featureFilesFolder,
  stepDefinitionsFolder
});
const testOptions = (0, _configUtils.getTestUseOptions)({
  trace,
  video,
  viewport,
  testIdAttribute
});

/**
 * Playwright configuration object
 *
 * @returns {import('@playwright/test').PlaywrightTestConfig}
 */
function getPlaywrightConfig() {
  const playwrightConfig = {
    testDir,
    globalTimeout: globalTimeout || 3600000,
    outputDir: _path.default.join(process.cwd(), 'uat', 'test-results'),
    fullyParallel: true,
    forbidOnly: false,
    reporter: [['html', {
      outputFolder: reportPath,
      open: openReportOn
    }], ['list'], ['./custom-reporter.js']],
    timeout: testTimeout,
    expect: {
      timeout: expectTimeout
    },
    use: testOptions,
    projects: isAuthMode ? [{
      name: 'setup',
      testMatch: /.*\.setup\.js/,
      testDir: _path.default.join(process.cwd(), 'uat'),
      teardown: 'cleanup'
    }, {
      name: 'cleanup',
      testMatch: /.*\.teardown\.js/,
      testDir: _path.default.join(process.cwd(), 'uat')
    }, ...projects] : [...projects],
    ...uatConfig.getAll()
  };
  return playwrightConfig;
}
var _default = exports.default = (0, _test.defineConfig)(getPlaywrightConfig());